export declare const updateCallbackReadMeStr = "# \u793A\u4F8B\u4EE3\u7801\n```\nfunction (particle, dt) {\n    const gravityVector = new Cesium.Cartesian3();\n    const gravity = -(9.8 * 9.8);\n    // Compute a local up vector for each particle in geocentric space.\n    const position = particle.position;\n\n    Cesium.Cartesian3.normalize(position, gravityVector);\n    Cesium.Cartesian3.multiplyByScalar(\n        gravityVector,\n        gravity * dt,\n        gravityVector\n    );\n\n    particle.velocity = Cesium.Cartesian3.add(particle.velocity, gravityVector, particle.velocity);\n}\n```\n\n# \u89C4\u683C\u8BF4\u660E\n```\n/**\n * A particle emitted by a {@link ParticleSystem}.\n * @param options - An object with the following properties:\n * @param [options.mass = 1.0] - The mass of the particle in kilograms.\n * @param [options.position = Cartesian3.ZERO] - The initial position of the particle in world coordinates.\n * @param [options.velocity = Cartesian3.ZERO] - The velocity vector of the particle in world coordinates.\n * @param [options.life = Number.MAX_VALUE] - The life of the particle in seconds.\n * @param [options.image] - The URI, HTMLImageElement, or HTMLCanvasElement to use for the billboard.\n * @param [options.startColor = Color.WHITE] - The color of a particle when it is born.\n * @param [options.endColor = Color.WHITE] - The color of a particle when it dies.\n * @param [options.startScale = 1.0] - The scale of the particle when it is born.\n * @param [options.endScale = 1.0] - The scale of the particle when it dies.\n * @param [options.imageSize = new Cartesian2(1.0, 1.0)] - The dimensions, width by height, to scale the particle image in pixels.\n */\nexport class Particle {\n    constructor(options: {\n        mass?: number;\n        position?: Cartesian3;\n        velocity?: Cartesian3;\n        life?: number;\n        image?: any;\n        startColor?: Color;\n        endColor?: Color;\n        startScale?: number;\n        endScale?: number;\n        imageSize?: Cartesian2;\n    });\n    /**\n     * The mass of the particle in kilograms.\n     */\n    mass: number;\n    /**\n     * The positon of the particle in world coordinates.\n     */\n    position: Cartesian3;\n    /**\n     * The velocity of the particle in world coordinates.\n     */\n    velocity: Cartesian3;\n    /**\n     * The life of the particle in seconds.\n     */\n    life: number;\n    /**\n     * The image to use for the particle.\n     */\n    image: any;\n    /**\n     * The color of the particle when it is born.\n     */\n    startColor: Color;\n    /**\n     * The color of the particle when it dies.\n     */\n    endColor: Color;\n    /**\n     * the scale of the particle when it is born.\n     */\n    startScale: number;\n    /**\n     * The scale of the particle when it dies.\n     */\n    endScale: number;\n    /**\n     * The dimensions, width by height, to scale the particle image in pixels.\n     */\n    imageSize: Cartesian2;\n    /**\n     * Gets the age of the particle in seconds.\n     */\n    age: number;\n    /**\n     * Gets the age normalized to a value in the range [0.0, 1.0].\n     */\n    normalizedAge: number;\n}\n```\n\n";
